@@ -4,6 +4,7 @@ mod sync;
 use std::sync::atomic::AtomicU64;
 
 pub use r#async::BufferUnorderedAsync;
+use serde_derive::{Deserialize, Serialize};
 pub use sync::BufferUnorderedSync;
 
 #[derive(Debug)]
@@ -14,7 +15,7 @@ pub struct BufferUnorderedStats {
     pub parallel_total: AtomicU64,
 }
 
-#[derive(Copy, Clone, Debug)]
+#[derive(Copy, Clone, Debug, Serialize, Deserialize)]
 pub struct BufferUnorderedConfig {
     pub buffer_size: usize,
     pub max_parallel: usize,
@@ -69,6 +70,9 @@ macro_rules! buffer_unordered_poller_macro {
                                         stats.clone(),
                                     ));
                                 }
+                                Request::Action(Action::Init) => {
+                                    stx.send(Event::Ready).ok();
+                                }
                                 Request::Action(Action::Flush) => need_flush = true,
                                 Request::Action(Action::Close) => rx.close(),
                                 Request::Action(Action::Sync) => {
@@ -96,7 +100,8 @@ macro_rules! buffer_unordered_poller_macro {
                                 Poll::Pending => return Poll::Pending,
                                 Poll::Ready(Some((mid, resp))) => {
                                     let resp: Result<_, $t::Error> = resp;
-                                    stx.send(Event::Response(mid, resp.map_err(Error::Other))).ok();
+                                    stx.send(Event::Response(mid, resp.map_err(Error::Other)))
+                                        .ok();
                                 }
                                 Poll::Ready(None) => break,
                             }
@@ -114,7 +119,8 @@ macro_rules! buffer_unordered_poller_macro {
                                 Poll::Pending => return Poll::Pending,
                                 Poll::Ready(resp) => {
                                     let resp: Result<_, E> = resp;
-                                    stx.send(Event::Synchronized(resp.map_err(Error::Other))).ok();
+                                    stx.send(Event::Synchronized(resp.map_err(Error::Other)))
+                                        .ok();
                                 }
                             }
                             need_sync = false;
