@@ -7,15 +7,15 @@ use std::{
     task::{Context, Poll},
 };
 
+use super::{BufferUnorderedConfig, BufferUnorderedStats};
 use crate::{
-    buffer_unordered_poller_macro, 
+    buffer_unordered_poller_macro,
     builder::ReceiverSubscriberBuilder,
-    error::{Error, StdSyncSendError, SendError}, 
-    receiver::{Action, Event, ReciveTypedReceiver, SendUntypedReceiver, SendTypedReceiver}, 
+    error::{Error, SendError, StdSyncSendError},
+    receiver::{Action, Event, ReciveTypedReceiver, SendTypedReceiver, SendUntypedReceiver},
     receivers::{fix_type, Request},
     Bus, Handler, Message, Untyped,
 };
-use super::{BufferUnorderedConfig, BufferUnorderedStats};
 
 use futures::{stream::FuturesUnordered, Future, StreamExt};
 use parking_lot::Mutex;
@@ -105,7 +105,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, msg: Action) -> Result<(), SendError<Action>> {
+    fn send(&self, msg: Action, _bus: &Bus) -> Result<(), SendError<Action>> {
         match self.tx.send(Request::Action(msg)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Action(msg))) => Err(SendError::Closed(msg)),
@@ -120,7 +120,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, mid: u64, m: M) -> Result<(), SendError<M>> {
+    fn send(&self, mid: u64, m: M, _bus: &Bus) -> Result<(), SendError<M>> {
         match self.tx.send(Request::Request(mid, m)) {
             Ok(_) => {
                 self.stats.buffer.fetch_add(1, Ordering::Relaxed);
@@ -139,7 +139,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn poll_events(&self, ctx: &mut Context<'_>) -> Poll<Event<R, E>> {
+    fn poll_events(&self, ctx: &mut Context<'_>, _bus: &Bus) -> Poll<Event<R, E>> {
         let poll = self.srx.lock().poll_recv(ctx);
         match poll {
             Poll::Pending => Poll::Pending,
