@@ -4,6 +4,7 @@ mod sync;
 use std::sync::atomic::AtomicU64;
 
 pub use r#async::BufferUnorderedBatchedAsync;
+use serde_derive::{Deserialize, Serialize};
 pub use sync::BufferUnorderedBatchedSync;
 
 #[derive(Debug)]
@@ -16,7 +17,7 @@ pub struct BufferUnorderedBatchedStats {
     pub batch_size: AtomicU64,
 }
 
-#[derive(Copy, Clone, Debug)]
+#[derive(Copy, Clone, Debug, Serialize, Deserialize)]
 pub struct BufferUnorderedBatchedConfig {
     pub buffer_size: usize,
     pub max_parallel: usize,
@@ -75,6 +76,9 @@ macro_rules! buffer_unordered_batch_poller_macro {
                                     buffer_mid.push(mid);
                                     buffer.push(msg);
                                 }
+                                Request::Action(Action::Init) => {
+                                    stx.send(Event::Ready).ok();
+                                }
                                 Request::Action(Action::Flush) => need_flush = true,
                                 Request::Action(Action::Close) => rx.close(),
                                 Request::Action(Action::Sync) => {
@@ -145,7 +149,11 @@ macro_rules! buffer_unordered_batch_poller_macro {
                                     }
                                     Err(er) => {
                                         for mid in mids {
-                                            stx.send(Event::Response(mid, Err(Error::Other(er.clone())))).ok();
+                                            stx.send(Event::Response(
+                                                mid,
+                                                Err(Error::Other(er.clone())),
+                                            ))
+                                            .ok();
                                         }
                                     }
                                 },
@@ -165,7 +173,8 @@ macro_rules! buffer_unordered_batch_poller_macro {
                                 Poll::Pending => return Poll::Pending,
                                 Poll::Ready(resp) => {
                                     let resp: Result<_, $t::Error> = resp;
-                                    stx.send(Event::Synchronized(resp.map_err(Error::Other))).ok();
+                                    stx.send(Event::Synchronized(resp.map_err(Error::Other)))
+                                        .ok();
                                 }
                             }
                             need_sync = false;
