@@ -9,9 +9,9 @@ use futures::Future;
 
 use super::SynchronizedConfig;
 use crate::{
-    error::{Error, StdSyncSendError, SendError},
     builder::ReceiverSubscriberBuilder,
-    receiver::{SendTypedReceiver, Action, Event, ReciveTypedReceiver, SendUntypedReceiver},
+    error::{Error, SendError, StdSyncSendError},
+    receiver::{Action, Event, ReciveTypedReceiver, SendTypedReceiver, SendUntypedReceiver},
     receivers::{fix_type, Request},
     AsyncSynchronizedHandler, Bus, Message, Untyped,
 };
@@ -81,7 +81,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, m: Action) -> Result<(), SendError<Action>> {
+    fn send(&self, m: Action, _bus: &Bus) -> Result<(), SendError<Action>> {
         match self.tx.send(Request::Action(m)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Action(msg))) => Err(SendError::Closed(msg)),
@@ -96,7 +96,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn send(&self, mid: u64, m: M) -> Result<(), SendError<M>> {
+    fn send(&self, mid: u64, m: M, _bus: &Bus) -> Result<(), SendError<M>> {
         match self.tx.send(Request::Request(mid, m)) {
             Ok(_) => Ok(()),
             Err(mpsc::error::SendError(Request::Request(_, msg))) => Err(SendError::Closed(msg)),
@@ -111,7 +111,7 @@ where
     R: Message,
     E: StdSyncSendError,
 {
-    fn poll_events(&self, ctx: &mut Context<'_>) -> Poll<Event<R, E>> {
+    fn poll_events(&self, ctx: &mut Context<'_>, _bus: &Bus) -> Poll<Event<R, E>> {
         let poll = self.srx.lock().poll_recv(ctx);
         match poll {
             Poll::Pending => Poll::Pending,
