@@ -4,6 +4,7 @@ mod sync;
 use std::sync::atomic::AtomicU64;
 
 pub use r#async::SynchronizedAsync;
+use serde_derive::{Deserialize, Serialize};
 pub use sync::SynchronizedSync;
 
 #[derive(Debug)]
@@ -12,7 +13,7 @@ pub struct SynchronizedStats {
     pub buffer_total: AtomicU64,
 }
 
-#[derive(Copy, Clone, Debug)]
+#[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct SynchronizedConfig {
     pub buffer_size: usize,
 }
@@ -51,7 +52,8 @@ macro_rules! synchronized_poller_macro {
                         Poll::Pending => return Poll::Pending,
                         Poll::Ready((mid, resp)) => {
                             let resp: Result<_, $t::Error> = resp;
-                            stx.send(Event::Response(mid, resp.map_err(Error::Other))).ok();
+                            stx.send(Event::Response(mid, resp.map_err(Error::Other)))
+                                .ok();
                         }
                     }
                 }
@@ -68,6 +70,9 @@ macro_rules! synchronized_poller_macro {
                                 stx.send(Event::Flushed).ok();
                                 continue;
                             }
+                            Request::Action(Action::Init) => {
+                                stx.send(Event::Ready).ok();
+                            }
                             Request::Action(Action::Sync) => need_sync = true,
                             Request::Action(Action::Close) => {
                                 rx.close();
@@ -91,7 +96,8 @@ macro_rules! synchronized_poller_macro {
                             Poll::Ready(resp) => {
                                 need_sync = false;
                                 let resp: Result<_, $t::Error> = resp;
-                                stx.send(Event::Synchronized(resp.map_err(Error::Other))).ok();
+                                stx.send(Event::Synchronized(resp.map_err(Error::Other)))
+                                    .ok();
                             }
                         }
                         sync_future = None;
